Accepts a character vector of instrument names and returns the corresponding OpenAQ instrument IDs.
Examples
if (FALSE) { # \dontrun{
OpenAQ_instrumentToID(c("BAM 1020", "PurpleAir PA-II", "Unknown"))
} # }
Accepts a character vector of instrument names and returns the corresponding OpenAQ instrument IDs.
if (FALSE) { # \dontrun{
OpenAQ_instrumentToID(c("BAM 1020", "PurpleAir PA-II", "Unknown"))
} # }