Accepts a character vector of license names and returns the corresponding OpenAQ license IDs.
Examples
if (FALSE) { # \dontrun{
OpenAQ_licenseToID(c("CC BY 4.0", "Public Domain", "Unknown"))
} # }
Accepts a character vector of license names and returns the corresponding OpenAQ license IDs.
if (FALSE) { # \dontrun{
OpenAQ_licenseToID(c("CC BY 4.0", "Public Domain", "Unknown"))
} # }