Subsets a *pat* object by date. This function always filters to day-boundaries. For sub-day filtering, use `pat_filterDatetime()`.
Dates can be anything that is understood by `MazamaCoreUtils::parseDatetime()` including either of the following recommended formats:
`"YYYYmmdd"`
`"YYYY-mm-dd"`
Timezone determination precedence assumes that if you are passing in `POSIXct` values then you know what you are doing.
get timezone from `startdate` if it is `POSIXct`
use passed in `timezone`
get timezone from `pat`
Usage
pat_filterDate(
pat = NULL,
startdate = NULL,
enddate = NULL,
timezone = NULL,
unit = "sec",
ceilingStart = FALSE,
ceilingEnd = FALSE
)Arguments
- pat
*pat* object.
- startdate
Desired start datetime (ISO 8601).
- enddate
Desired end datetime (ISO 8601).
- timezone
Olson timezone used to interpret dates.
- unit
Units used to determine time at end-of-day.
- ceilingStart
Logical instruction to apply [lubridate::ceiling_date()] to the `startdate` rather than [lubridate::floor_date()]
- ceilingEnd
Logical instruction to apply [lubridate::ceiling_date()] to the `enddate` rather than [lubridate::floor_date()]
Value
A subset of the incoming *pat* time series object. (A list with `meta` and `data` dataframes.)