Convenience function for `nrow(pat$data) == 0`. This makes for more readable code in functions that need to test for this.
Examples
library(AirSensor2)
pat_isEmpty(example_pat)
#> [1] FALSE
Convenience function for `nrow(pat$data) == 0`. This makes for more readable code in functions that need to test for this.
library(AirSensor2)
pat_isEmpty(example_pat)
#> [1] FALSE