R/Clarity_updateAllOpenMonitors.R
Clarity_updateAllOpenMonitors.RdDownload, parse and enhance the last 3 hours of data from all Clarity "open" sensors and append new data to the incoming Clarity *mts_monitor* object package.
Clarity API READ Key. If `api_key = NULL`, it will be obtained using `getAPIKey("Clarity-read")`.
Previously generated *mts_monitor* object.
Customized output format ("USFS2", "USFS").
Parameter to use for data ("pm2.5" or "nowcast")
Logical specifying whether to use the Clarity QCFlag to invalidate data values.
Vector of ISO 3166-1 alpha-2 country codes used to filter available data.
An AirMonitor package *mts_monitor* object.
Maintenance of unique device-deployments will be preserved. If any Clarity sensor is reported as having a new location, a new deployment will be created as a separate time series.