R/OpenAQ_downloadRawLocations.R
OpenAQ_downloadRawLocations.RdDownloads raw location metadata from OpenAQ and optionally retrieves additional pages when many matching locations are found.
OpenAQ_downloadRawLocations(
bbox = NULL,
providers_id = NULL,
manufacturers_id = NULL,
monitor = NULL,
mobile = FALSE,
countries_id = NULL,
limit = 1000,
maxPages = 1,
sleepSeconds = 0.2,
api_key = NULL
)Bounding box passed to [openaq::list_locations()].
Provider IDs passed to [openaq::list_locations()].
Manufacturer IDs passed to [openaq::list_locations()].
Logical value passed to [openaq::list_locations()].
Logical value passed to [openaq::list_locations()].
Country IDs passed to [openaq::list_locations()].
Maximum number of records to request per page.
Maximum number of pages to request automatically.
Number of seconds to pause between additional requests.
OpenAQ API key.
A dataframe of raw OpenAQ location metadata.
When more matching locations are available than can be returned in a single request, this function can automatically request additional pages up to `maxPages`. If more pages may still be available after `maxPages` pages have been retrieved, a warning is issued suggesting that the user narrow the request.