Three successive steps are used to guarantee that the `datetime` axis contains no repeated values:
remove any duplicate records
guarantee that rows are in `datetime` order
average together fields for any remaining records that share the same `datetime`
pat_distinct(pat)An *pat* object where each record is associated with a unique time. (A list with `meta` and `data` dataframes.)