Generates color palettes for PurpleAir synoptic data with the intention of having a reproducible functional color generator. Default palettes are available for the following parameters:
"pm2.5"
"humidity
"temperature
synoptic_palette(synoptic = NULL, parameter = "pm2.5", paletteName = NULL, ...)A list containing: 1) a label and color dataframe; and 2) a vector of color values calculated from the data found in `synoptic`.